/*
 *  Copyright (C) 2004-2013 Savoir-Faire Linux Inc.
 *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#ifndef ICON_FACTORY_H
#define ICON_FACTORY_H

#define GTK_STOCK_PICKUP                "gnome-stock-pickup"
#define GTK_STOCK_HANGUP                "gnome-stock-hangup"
#define GTK_STOCK_ONHOLD                "gnome-stock-onhold"
#define GTK_STOCK_OFFHOLD               "gnome-stock-offhold"
#define GTK_STOCK_IM                    "gnome-stock-im"
#define GTK_STOCK_TRANSFER              "gnome-stock-transfer"
#define GTK_STOCK_DIAL                  "gnome-stock-dial"
#define GTK_STOCK_CALL_CURRENT          "gnome-stock-call-current"
#define GTK_STOCK_ADDRESSBOOK           "gnome-stock-addressbook"
#define GTK_STOCK_CALLS                 "gnome-stock-calls"
#define GTK_STOCK_SFLPHONE              "gnome-stock-sflphone"
#define GTK_STOCK_FAIL                  "gnome-stock-fail"
#define GTK_STOCK_USER                  "gnome-stock-user"
#define GTK_STOCK_SCREENSHARING         "gnome-stock-screensharing"
#define GTK_STOCK_RECORD                "gnome-stock-record"
#define GTK_STOCK_HISTORY               "gnome-stock-history"
#define GTK_STOCK_VOICEMAIL             "gnome-stock-voicemail"
#define GTK_STOCK_NEWVOICEMAIL          "gnome-stock-newvoicemail"
#define GTK_STOCK_PREFS                 "gnome-stock-prefs"
#define GTK_STOCK_PREFS_AUDIO           "gnome-stock-prefs-audio"
#define GTK_STOCK_PREFS_VIDEO           "gnome-stock-prefs-video"
#define GTK_STOCK_PREFS_SHORTCUT        "gnome-stock-prefs-shortcut"
#define GTK_STOCK_PREFS_HOOK            "gnome-stock-prefs-hook"
#define GTK_STOCK_PREFS_ADDRESSBOOK     "gnome-stock-prefs-addressbook"

void init_icon_factory();

#endif
